==> qbittorrent_4.1.7.orig.tar.xz: qbittorrent-4.1.7/src/gui/search/searchwidget.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015, 2018  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QList>
#include <QPointer>
#include <QWidget>

class QShortcut;
class QSignalMapper;
class QTabWidget;

class MainWindow;
class SearchJobWidget;

namespace Ui
{
    class SearchWidget;
}

class SearchWidget : public QWidget
{
    Q_OBJECT
    Q_DISABLE_COPY(SearchWidget)

public:
    explicit SearchWidget(MainWindow *mainWindow);
    ~SearchWidget() override;

    void giveFocusToSearchInput();

private slots:
    void on_searchButton_clicked();
    void on_downloadButton_clicked();
    void on_goToDescBtn_clicked();
    void on_copyURLBtn_clicked();
    void on_pluginsButton_clicked();

private:
    void tabChanged(int index);
    void closeTab(int index);
    void resultsCountUpdated();
    void tabStatusChanged(QWidget *tab);
    void selectMultipleBox(int index);
    void toggleFocusBetweenLineEdits();

    void fillCatCombobox();
    void fillPluginComboBox();
    void selectActivePage();
    void searchTextEdited(QString);
    void updateButtons();

    QString selectedCategory() const;
    QString selectedPlugin() const;

    Ui::SearchWidget *m_ui;
    QSignalMapper *m_tabStatusChangedMapper;
    QPointer<SearchJobWidget> m_currentSearchTab; // Selected tab
    QPointer<SearchJobWidget> m_activeSearchTab; // Tab with running search
    QList<SearchJobWidget *> m_allTabs; // To store all tabs
    MainWindow *m_mainWindow;
    bool m_isNewQueryString;
    QShortcut *m_focusSearchHotkey;
};

==> qbittorrent_4.2.5.orig.tar.xz: qbittorrent-4.2.5/src/gui/search/searchwidget.h <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015, 2018  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#pragma once

#include <QList>
#include <QPointer>
#include <QWidget>

class QTabWidget;

class MainWindow;
class SearchJobWidget;

namespace Ui
{
    class SearchWidget;
}

class SearchWidget : public QWidget
{
    Q_OBJECT
    Q_DISABLE_COPY(SearchWidget)

public:
    explicit SearchWidget(MainWindow *mainWindow);
    ~SearchWidget() override;

    void giveFocusToSearchInput();

private slots:
    void on_searchButton_clicked();
    void on_pluginsButton_clicked();

private:
    void tabChanged(int index);
    void closeTab(int index);
    void tabStatusChanged(QWidget *tab);
    void selectMultipleBox(int index);
    void toggleFocusBetweenLineEdits();

    void fillCatCombobox();
    void fillPluginComboBox();
    void selectActivePage();
    void searchTextEdited(const QString &);

    QString selectedCategory() const;
    QString selectedPlugin() const;

    Ui::SearchWidget *m_ui;
    QPointer<SearchJobWidget> m_currentSearchTab; // Selected tab
    QPointer<SearchJobWidget> m_activeSearchTab; // Tab with running search
    QList<SearchJobWidget *> m_allTabs; // To store all tabs
    MainWindow *m_mainWindow;
    bool m_isNewQueryString;
};
